Stan Math Library: stan/math/fwd/scal/fun/asinh.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

asinh.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_ASINH_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_ASINH_HPP
3
4 #include <math.h>
5 #include <stan/math/fwd/core.hpp>
6 #include <stan/math/prim/scal/fun/square.hpp>
7 #include <cmath>
8
9 namespace stan {
10 namespace math {
11
12 template <typename T>
13 inline fvar<T> asinh(const fvar<T>& x) {
14 using ::asinh;
15 using std::sqrt;
16 using stan::math::square;
17 return fvar<T>(asinh(x.val_), x.d_ / sqrt(square(x.val_) + 1));
18 }
19
20 }
21 }
22 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
stan
Definition: log_sum_exp.hpp:8
square.hpp
stan::math::square
fvar< T > square(const fvar< T > &x)
Definition: square.hpp:15
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::asinh
fvar< T > asinh(const fvar< T > &x)
Definition: asinh.hpp:13
stan::math::asinh
var asinh(const var &a)
The inverse hyperbolic sine function for variables (C99).
Definition: asinh.hpp:67
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.